.. include:: ../references.txt

.. _survey_map:

Survey map
==========

Here's an example of a Gammapy analysis as a Python script:

.. literalinclude:: ../../examples/survey_map.py

To execute it run:

.. code-block:: bash

    $ python survey_example.py

For interactive use, IPython and Jupyter are great, and most Gammapy examples
use those. However, for long-running, non-interactive tasks like data reduction
or survey maps, you might prefer a Python script.
